Confluence - API to work with Atlassian Confluence (WIKI system)
================================================================

[![confluence build status](https://travis-ci.org/devopshq/confluence.svg)](https://travis-ci.org/devopshq/confluence) [![confluence code quality](https://api.codacy.com/project/badge/Grade/a8ed08da32214523868567d70a3df411)](https://www.codacy.com/app/tim55667757/confluence/dashboard) [![confluence code coverage](https://api.codacy.com/project/badge/Coverage/a8ed08da32214523868567d70a3df411)](https://www.codacy.com/app/tim55667757/confluence/dashboard) [![confluence on PyPI](https://img.shields.io/pypi/v/confluence.svg)](https://pypi.python.org/pypi/confluence) [![confluence license](https://img.shields.io/pypi/l/confluence.svg)](https://github.com/devopshq/confluence/blob/master/LICENSE)


***... Soon there will be an instruction ...***